<?php

namespace Pizi\Recruit\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Pizi\Recruit\Forms\Location as LocationForm;
use Pizi\Recruit\Http\Requests\LocationRequest;
use Pizi\Recruit\Interfaces\LocationRepositoryInterface;
use Pizi\Recruit\Repositories\Eloquent\Filters\LocationResourceFilter;
use Pizi\Recruit\Repositories\Eloquent\Presenters\LocationListPresenter;

/**
 * Resource controller class for location.
 */
class LocationResourceController extends BaseController
{

    /**
     * Initialize location resource controller.
     *
     *
     * @return null
     */
    public function __construct(LocationRepositoryInterface $location)
    {
        parent::__construct();
        $this->form = LocationForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('pizi.recruit.modules'), 'recruit', guard_url('recruit'));
        $this->repository = $location;
    }

    /**
     * Display a list of location.
     *
     * @return Response
     */
    public function index(LocationRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(LocationResourceFilter::class)
            ->setPresenter(LocationListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('recruit::location.names'))
            ->view('recruit::location.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display location.
     *
     * @param Request $request
     * @param Model   $location
     *
     * @return Response
     */
    public function show(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('recruit::location.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('recruit::location.show')
            ->output();
    }

    /**
     * Show the form for creating a new location.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('recruit::location.name'))
            ->view('recruit::location.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new location.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('recruit::location.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('recruit/location/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/recruit/location'))
                ->redirect();
        }

    }

    /**
     * Show location for editing.
     *
     * @param Request $request
     * @param Model   $location
     *
     * @return Response
     */
    public function edit(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('recruit::location.name'))
            ->view('recruit::location.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the location.
     *
     * @param Request $request
     * @param Model   $location
     *
     * @return Response
     */
    public function update(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('recruit::location.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('recruit/location/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('recruit/location/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the location.
     *
     * @param Model   $location
     *
     * @return Response
     */
    public function destroy(LocationRequest $request, LocationRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('recruit::location.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('recruit/location/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('recruit/location/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
